"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  default: () => VitePluginGraphQLCodegen
});
module.exports = __toCommonJS(src_exports);
var import_node_fs2 = __toESM(require("fs"));
var import_cli = require("@graphql-codegen/cli");

// src/helpers/isCodegenConfig.ts
var import_node_path = require("path");
function isCodegenConfig(filePath, context) {
  return (0, import_node_path.normalize)(context.filepath) === (0, import_node_path.normalize)(filePath);
}

// src/helpers/isGraphQLDocument.ts
var import_node_path2 = require("path");
var import_plugin_helpers = require("@graphql-codegen/plugin-helpers");
async function isGraphQLDocument(filePath, context) {
  const config = context.getConfig();
  if (!config.documents)
    return false;
  const normalized = (0, import_plugin_helpers.normalizeInstanceOrArray)(config.documents);
  const documents = await context.loadDocuments(normalized);
  if (!documents.length)
    return false;
  const paths = documents.map(({ location = "" }) => location).map(import_node_path2.normalize).filter(Boolean);
  if (!paths.length)
    return false;
  return paths.some((documentPath) => documentPath === (0, import_node_path2.normalize)(filePath));
}

// src/helpers/restartVite.ts
var import_node_fs = __toESM(require("fs"));
function restartVite(fileName) {
  if (!fileName)
    return;
  const time = new Date();
  try {
    import_node_fs.default.utimesSync(fileName, time, time);
  } catch (error) {
    import_node_fs.default.closeSync(import_node_fs.default.openSync(fileName, "w"));
  }
}

// src/helpers/viteModes.ts
var modes = {
  serve: "serve",
  build: "build"
};
var isServeMode = (mode) => mode === modes.serve;
var isBuildMode = (mode) => mode === modes.build;

// src/helpers/debugLog.ts
function debugLog(...args) {
  const LOG_PREFIX = "\x1B[36m[vite-plugin-graphql-codegen]\x1B[0m";
  console.log(LOG_PREFIX, ...args);
}

// src/index.ts
var VITE_CONFIG_FILE_NAMES = ["vite.config.ts", "vite.config.js"];
function VitePluginGraphQLCodegen(options) {
  let codegenContext;
  let viteMode;
  let viteConfigFileName;
  const {
    runOnStart = true,
    runOnBuild = true,
    enableWatcher = true,
    config = null,
    configOverride = {},
    configOverrideOnStart = {},
    configOverrideOnBuild = {},
    configOverrideWatcher = {},
    configFilePathOverride,
    debug = false
  } = options ?? {};
  const log = (...args) => {
    if (!debug)
      return;
    debugLog(...args);
  };
  const generateWithOverride = async (overrideConfig) => {
    const currentConfig = codegenContext.getConfig();
    return (0, import_cli.generate)({
      ...currentConfig,
      ...configOverride,
      ...overrideConfig,
      watch: false
    });
  };
  log("Plugin initialized with options:", options);
  return {
    name: "graphql-codegen",
    async config(_config, env) {
      try {
        if (config) {
          log("Manual config passed, creating codegen context");
          codegenContext = new import_cli.CodegenContext({ config });
        } else {
          const cwd = process.cwd();
          log("Loading codegen context:", configFilePathOverride ?? cwd);
          codegenContext = await (0, import_cli.loadContext)(configFilePathOverride);
        }
        log("Loading codegen context successful");
      } catch (error) {
        log("Loading codegen context failed");
        throw error;
      }
      viteMode = env.command;
    },
    configResolved() {
      for (const fileName of VITE_CONFIG_FILE_NAMES) {
        log("Checking for vite config file:", fileName);
        if (import_node_fs2.default.existsSync(fileName)) {
          viteConfigFileName = fileName;
          log("Vite config file found:", fileName);
          break;
        }
      }
    },
    async buildStart() {
      const isServe = isServeMode(viteMode);
      const isBuild = isBuildMode(viteMode);
      if (isServe && !runOnStart)
        return;
      if (isBuild && !runOnBuild)
        return;
      try {
        if (isServe)
          await generateWithOverride(configOverrideOnStart);
        if (isBuild)
          await generateWithOverride(configOverrideOnBuild);
        isServe && log("Generation successful on start");
        isBuild && log("Generation successful on build");
      } catch (error) {
        isServe && log("Generation failed on start");
        isBuild && log("Generation failed on build");
        if (isBuild)
          throw error;
      }
    },
    configureServer(server) {
      const listener = async (filePath = "") => {
        log("File changed:", filePath);
        const isConfig = isCodegenConfig(filePath, codegenContext);
        if (isConfig) {
          log("Codegen config file changed, restarting vite");
          restartVite(viteConfigFileName);
          return;
        }
        if (!enableWatcher)
          return;
        try {
          const isDocument = await isGraphQLDocument(filePath, codegenContext);
          log("Document check successful in file watcher");
          if (!isDocument)
            return;
        } catch (error) {
          log("Document check failed in file watcher");
        }
        log("File matched a graphql document");
        try {
          await generateWithOverride(configOverrideWatcher);
          log("Generation successful in file watcher");
        } catch (error) {
          log("Generation failed in file watcher");
        }
      };
      server.watcher.on("add", listener);
      server.watcher.on("change", listener);
    }
  };
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
//# sourceMappingURL=index.js.map